@@ -2,10 +2,10 @@ import os
 from pathlib import Path
 from typing import Union
 
+from restit._response import Response
 from restit.internal.suffix_media_type_mapping import SUFFIX_MEDIA_TYPE_MAPPING
 from restit.request import Request
 from restit.resource import Resource
-from restit.response import Response
 
 
 class StaticDirectoryResource(Resource):
@@ -23,6 +23,8 @@ class StaticDirectoryResource(Resource):
             file_content = fp.read()
 
         _, suffix = os.path.splitext(file_name)
-        content_type = SUFFIX_MEDIA_TYPE_MAPPING.get(suffix, )
+        content_type = SUFFIX_MEDIA_TYPE_MAPPING.get(
+            suffix,
+        )
 
         return Response(file_content, headers={"Content-Type": content_type})
